@@ -5,10 +5,10 @@ package CPAN::Meta::X;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-10-28'; # DATE
 our $DIST = 'CPAN-Meta-X'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 1;
-# ABSTRACT: Custom (x_*) keys in CPAN distribution metadata being used in the wild
+# ABSTRACT: Catalog of custom (x_*) keys in CPAN distribution metadata being used in the wild
 
 __END__
 
@@ -18,11 +18,11 @@ __END__
 
 =head1 NAME
 
-CPAN::Meta::X - Custom (x_*) keys in CPAN distribution metadata being used in the wild
+CPAN::Meta::X - Catalog of custom (x_*) keys in CPAN distribution metadata being used in the wild
 
 =head1 VERSION
 
-This document describes version 0.008 of CPAN::Meta::X (from Perl distribution CPAN-Meta-X), released on 2022-10-28.
+This document describes version 0.009 of CPAN::Meta::X (from Perl distribution CPAN-Meta-X), released on 2022-10-28.
 
 =head1 DESCRIPTION
 
